#

##

##

##

    shares

    ZSH code

    	pip install shares

    ZSH code

    Started from the shell, "shares" presents files in the current working directory (cwd) that have extension "s.HTML".

    	shares

    python3 code

    	import pathlib
    	from os.path import dirname, join, normpath
    	this_folder = pathlib.Path (__file__).parent.resolve ()

    	import Titaness.topics.help_documentation as help_documentation
    	help_documentation.start ({
    		"directory": str (this_folder) + "/structures/shares",
    		"extension": ".s.HTML",
    		"relative path": str (this_folder) + "/structures/shares"
    	})